<!DOCTYPE html>
<html lang="en" xmlns="http://www.w3.org/1999/xhtml" xmlns:v="urn:schemas-microsoft-com:vml" xmlns:o="urn:schemas-microsoft-com:office:office">
  <head>
    {% include "mail/head.html" %}
    {% block extra_head %}{% endblock %}
  </head>
  <body class="" style="background-color: #f6f6f6; font-family: sans-serif; -webkit-font-smoothing: antialiased; font-size: 14px; line-height: 1.4; margin: 0; padding: 0; -ms-text-size-adjust: 100%; -webkit-text-size-adjust: 100%;">
    <center style="width: 100%; background-color: #222222;">
    <!--[if mso | IE]>
    <table role="presentation" border="0" cellpadding="0" cellspacing="0" width="100%" style="background-color: #222222;">
    <tr>
    <td>
    <![endif]-->
    <table role="presentation" border="0" cellpadding="0" cellspacing="0" class="body" style="border-collapse: separate; mso-table-lspace: 0pt; mso-table-rspace: 0pt; width: 100%; background-color: #f6f6f6;">
      <tr>
        <td style="font-family: sans-serif; font-size: 14px; vertical-align: top;">&nbsp;</td>
        <td class="container" style="font-family: sans-serif; font-size: 14px; vertical-align: top; display: block; margin: 0 auto; max-width: 580px; padding: 10px; width: 580px;">
          <div class="content" style="box-sizing: border-box; display: block; margin: 0 auto; max-width: 580px; padding: 10px;">

            <!-- START CENTERED WHITE CONTAINER -->
            <span class="preheader" style="color: transparent; display: none; height: 0; max-height: 0; max-width: 0; opacity: 0; overflow: hidden; mso-hide: all; visibility: hidden; width: 0;">
              {% block preheader %}{% endblock %}
            </span>
            <table role="presentation" class="main" border="0" style="border-collapse: separate; mso-table-lspace: 0pt; mso-table-rspace: 0pt; width: 100%; background: #ffffff;">
              <!-- START LOGO AND BANNER AREA -->
              <tr>
                <td class="wrapper" style="font-family: Roboto, Helvetica, Arial, sans-serif; font-size: 14px; vertical-align: top; box-sizing: border-box; padding: 0;">
                  {% include "mail/head-table.html" %}
                </td>
              </tr>
              <!-- END LOGO AND BANNER -->

              <!-- START MAIN CONTENT AREA -->
              <tr>
                <td class="wrapper" style="font-family: Roboto, Helvetica, Arial, sans-serif; font-size: 14px; vertical-align: top; box-sizing: border-box; padding: 20px;">
                  <table role="presentation" border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; mso-table-lspace: 0pt; mso-table-rspace: 0pt; width: 100%;">
                    <tr>
                      <td style="font-family: Roboto, Helvetica, Arial, sans-serif; font-size: 14px; font-weight:normal; vertical-align: top;">
                        {% block message_title_wrapper %}
                          <h1 style="font-size: 16px; font-weight: bold; margin: 0; margin-bottom: 15px;">
                            {% block message_title %}
                              A message from arXiv
                            {% endblock %}
                          </h1>
                        {% endblock %}

                        {% block message_body %}
                        <p style="margin: 0; margin-bottom: 15px;">This is a <b>test message</b><br />
                        If you are seeing this in the wild, <a href="mailto:support@arxiv.org" style="color: #0068ac; text-decoration: underline;"><font color="#0068ac">let us know</font></a>.</p>
                        {% endblock %}

                        {% block signature %}
                          <p style="margin: 0; margin-bottom: 15px;">- arXiv admin</p>
                        {% endblock %}

                      </td>
                    </tr>
                  </table>
                </td>
              </tr>

            <!-- END MAIN CONTENT AREA -->
            </table>

            <!-- START FOOTER -->
            {% include "mail/footer-table.html" %}
            <!-- END FOOTER -->

          <!-- END CENTERED WHITE CONTAINER -->
          </div>
        </td>
        <td style="font-family: sans-serif; font-size: 14px; vertical-align: top;">&nbsp;</td>
      </tr>
    </table>
    <!--[if mso | IE]>
    </td>
    </tr>
    </table>
    <![endif]-->
  </center>
  </body>
</html>
