{% extends "base/exception.html" %}

{% block error_title %}Request Entity Too Large{% endblock %}

{% block error_illustration %}
<div class="column">
  <span>4</span>
</div>
<div class="column">
  <span>1</span>
</div>
<div class="column">
  <span>3</span>
</div>
{% endblock %}
