<table role="presentation" border="0" cellpadding="0" cellspacing="0" style="border-collapse: separate; mso-table-lspace: 0pt; mso-table-rspace: 0pt; border-bottom: 3px solid #B31B1B;" width="100%">
  <tr>
    <td bgcolor="#B31B1B" align="center" valign="center" width="100px" style="padding: 10px 20px 10px 20px; color: #FFFFFF; font-family: sans-serif; font-weight: bold; font-size: 28px; line-height: 1.1;">
      <img src="https://static.arxiv.org/static/base/0.14.1/images/arxiv-logo-web.svg" alt="arXiv" aria-label="logo" width="85" height="25" style="display: block;" />
    </td>
    <td style="font-size: 0; line-height: 0;" height="20">
      &nbsp;
    </td>
  </tr>
</table>
